@@ -17,16 +17,20 @@ limitations under the License.
 import json
 from langtrace.trace_attributes import DatabaseSpanAttributes
 from langtrace_python_sdk.utils.silently_fail import silently_fail
-from langtrace_python_sdk.utils.llm import set_span_attributes
-from opentelemetry import baggage
+from langtrace_python_sdk.utils import set_span_attribute
+from opentelemetry import baggage, trace
 from opentelemetry.trace import SpanKind
 from opentelemetry.trace.status import Status, StatusCode
+from opentelemetry.trace.propagation import set_span_in_context
 
 from langtrace_python_sdk.constants.instrumentation.common import (
     LANGTRACE_ADDITIONAL_SPAN_ATTRIBUTES_KEY,
     SERVICE_PROVIDERS,
 )
 from langtrace_python_sdk.constants.instrumentation.qdrant import APIS
+from importlib_metadata import version as v
+
+from langtrace_python_sdk.constants import LANGTRACE_SDK_NAME
 
 
 def collection_patch(method, version, tracer):
@@ -44,7 +48,7 @@ def collection_patch(method, version, tracer):
             "langtrace.service.name": service_provider,
             "langtrace.service.type": "vectordb",
             "langtrace.service.version": version,
-            "langtrace.version": "1.0.0",
+            "langtrace.version": v(LANGTRACE_SDK_NAME),
             "db.system": "qdrant",
             "db.operation": api["OPERATION"],
             "db.query": json.dumps(kwargs.get("query")),
@@ -53,10 +57,14 @@ def collection_patch(method, version, tracer):
 
         attributes = DatabaseSpanAttributes(**span_attributes)
 
-        with tracer.start_as_current_span(api["METHOD"], kind=SpanKind.CLIENT) as span:
+        with tracer.start_as_current_span(
+            api["METHOD"],
+            kind=SpanKind.CLIENT,
+            context=set_span_in_context(trace.get_current_span()),
+        ) as span:
             collection_name = kwargs.get("collection_name") or args[0]
             operation = api["OPERATION"]
-            set_span_attributes(span, "db.collection.name", collection_name)
+            set_span_attribute(span, "db.collection.name", collection_name)
 
             if operation == "add":
                 _set_upload_attributes(span, args, kwargs, "documents")
@@ -103,7 +111,7 @@ def _set_upsert_attributes(span, args, kwargs):
     else:
         # In case of using Batch.
         length = len(points.ids)
-    set_span_attributes(span, "db.upsert.points_count", length)
+    set_span_attribute(span, "db.upsert.points_count", length)
 
 
 @silently_fail
@@ -115,16 +123,16 @@ def _set_upload_attributes(span, args, kwargs, field):
         # In case of using Batch.
         length = len(docs.ids)
 
-    set_span_attributes(span, f"db.upload.{field}_count", length)
+    set_span_attribute(span, f"db.upload.{field}_count", length)
 
 
 @silently_fail
 def _set_search_attributes(span, args, kwargs):
     limit = kwargs.get("limit") or 10
-    set_span_attributes(span, "db.query.top_k", limit)
+    set_span_attribute(span, "db.query.top_k", limit)
 
 
 @silently_fail
 def _set_batch_search_attributes(span, args, kwargs, method):
     requests = kwargs.get("requests") or []
-    set_span_attributes(span, f"db.{method}.requests_count", len(requests))
+    set_span_attribute(span, f"db.{method}.requests_count", len(requests))
